@@ -98,7 +98,7 @@ class EmergeCommand(CommandExecutor):
     Запуск emerge для последующего анализирования
     """
     # параметры по умолчанию
-    default_params = ["-av", "--color=y", "--nospinner"]
+    default_params = ["-av", "--color=y", "--nospinner", "--jobs=1"]
     cmd = getProgPath("/usr/bin/emerge")
 
     def __init__(self, packages, extra_params=None, env=None, cwd=None,
